diff PalanthirCppClient/HttpClient.h @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents 33d67e1ab173
children
line wrap: on
line diff
--- a/PalanthirCppClient/HttpClient.h	Wed Sep 05 15:38:08 2012 +0200
+++ b/PalanthirCppClient/HttpClient.h	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -34,7 +34,7 @@
 #include <boost/shared_ptr.hpp>
 #include <json/json.h>
 
-namespace Palantir
+namespace Palanthir
 {
   class HttpClient
   {
@@ -43,8 +43,8 @@
     boost::shared_ptr<PImpl> pimpl_;
 
     std::string url_;
-    Palantir_HttpMethod method_;
-    Palantir_HttpStatus lastStatus_;
+    Palanthir_HttpMethod method_;
+    Palanthir_HttpStatus lastStatus_;
     std::string postData_;
     bool isVerbose_;
 
@@ -68,12 +68,12 @@
       return url_;
     }
 
-    void SetMethod(Palantir_HttpMethod method)
+    void SetMethod(Palanthir_HttpMethod method)
     {
       method_ = method;
     }
 
-    Palantir_HttpMethod GetMethod() const
+    Palanthir_HttpMethod GetMethod() const
     {
       return method_;
     }
@@ -99,7 +99,7 @@
 
     bool Apply(Json::Value& answer);
 
-    Palantir_HttpStatus GetLastStatus() const
+    Palanthir_HttpStatus GetLastStatus() const
     {
       return lastStatus_;
     }
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium